# Disclaimer: alpha - preview

# PDL - Python Download Library

High level library for downloading and unarchiving files.

# Install

```bash
pip install pdl
```

# How to use

```python

import pdl

pdl.pdl(url, data_dir, keep_download=False, overwrite_download=False, verbose=False)

```
